@@ -9,10 +9,10 @@ from loguru import logger
 
 import tf2mon
 import tf2mon.layouts
+from tf2mon._controls import Controls
 from tf2mon._logger import configure_logger
 from tf2mon._monitor import Monitor
 from tf2mon.conlog import Conlog
-from tf2mon.controls import Controls
 from tf2mon.database import Database
 from tf2mon.steamweb import SteamWebAPI
 
@@ -477,12 +477,12 @@ class CLI(BaseCLI):
             self.parser.exit()
 
         if self.options.trunc_con_logfile:
-            Conlog(self.options.con_logfile).trunc()
+            Conlog(self.options).trunc()
             logger.info(f"con_logfile {str(self.options.con_logfile)!r} truncated; Exiting.")
             self.parser.exit()
 
         if self.options.clean_con_logfile:
-            Conlog(self.options.con_logfile, exclude_file=self.options.exclude_file).clean()
+            Conlog(self.options).clean()
             logger.info(f"con_logfile {str(self.options.con_logfile)!r} cleaned; Exiting.")
             self.parser.exit()
 
