@@ -1,6 +1,5 @@
 import re
 
-import tf2mon
 from tf2mon.regex import Regex
 
 
@@ -13,7 +12,6 @@ class GameEvent:
 
     @property
     def regex(self) -> Regex:
-        tf2mon.logger.debug(f"Compiling `{self.pattern}`")
         return Regex(self.leader + self.pattern, self.handler)
 
     def handler(self, match: re.Match) -> None:
